cloogle.py
====================

Basic interfacing with the Cloogle (https://cloogle.org) API.

See PyPi: https://pypi.python.org/pypi/cloogle

Source code: https://github.com/clean-cloogle/cloogle.py
